@@ -1,36 +1,8 @@
-# -*- coding: utf-8 -*-
 #
 #  main configuration registry classes
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2004-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2004-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """Univention Configuration Registry backend for data storage."""
 
@@ -41,25 +13,16 @@ import os
 import re
 import sys
 import time
-from collections.abc import Mapping, MutableMapping
+from collections.abc import ItemsView, Iterator, Mapping, MutableMapping
 from enum import IntEnum
 from stat import S_ISREG
+from types import TracebackType
+from typing import IO, Literal, NoReturn, Self, TypeVar, overload
 
 from univention.config_registry.handler import run_filter
 
 
-try:
-    from types import TracebackType  # noqa: F401
-    from typing import overload  # noqa: F811
-    from typing import (  # noqa: F401
-        IO, Any, Dict, ItemsView, Iterator, List, NoReturn, Optional, Set, Tuple, Type, TypeVar, Union,
-    )
-
-    from typing_extension import Literal  # noqa: F401
-    _T = TypeVar('_T', bound='ReadOnlyConfigRegistry')  # noqa: PYI018
-    _VT = TypeVar('_VT')  # noqa: PYI018
-except ImportError:  # pragma: no cover
-    pass
+_VT = TypeVar('_VT')
 
 __all__ = ['SCOPE', 'ConfigRegistry', 'StrictModeException', 'exception_occured']
 MYPY = False
@@ -70,15 +33,14 @@ class StrictModeException(Exception):
     """Attempt to store non-UTF-8 characters in strict UTF-8 mode."""
 
 
-def exception_occured(out=sys.stderr):
-    # type: (IO) -> NoReturn
+def exception_occured(out: IO = sys.stderr) -> NoReturn:
     """
     Print exception message and exit.
 
     :param out: Output stream for message.
     """
-    print(u'E: your request could not be fulfilled', file=out)
-    print(u'try `univention-config-registry --help` for more information', file=out)
+    print('E: your request could not be fulfilled', file=out)
+    print('try `univention-config-registry --help` for more information', file=out)
     sys.exit(1)
 
 
@@ -99,14 +61,13 @@ else:
     _MM = MutableMapping
 
 
-class BooleanConfigRegistry(object):
+class BooleanConfigRegistry:
     """Mixin class for boolean operations."""
 
     TRUE = frozenset({'yes', 'true', '1', 'enable', 'enabled', 'on'})
     FALSE = frozenset({'no', 'false', '0', 'disable', 'disabled', 'off'})
 
-    def is_true(self, key=None, default=False, value=None):
-        # type: (Optional[str], bool, Optional[str]) -> bool
+    def is_true(self, key: str | None = None, default: bool = False, value: str | None = None) -> bool:
         """
         Return if the strings value of key is considered as true.
 
@@ -132,8 +93,7 @@ class BooleanConfigRegistry(object):
                 return default
         return value.lower() in self.TRUE
 
-    def is_false(self, key=None, default=False, value=None):
-        # type: (Optional[str], bool, Optional[str]) -> bool
+    def is_false(self, key: str | None = None, default: bool = False, value: str | None = None) -> bool:
         """
         Return if the strings value of key is considered as false.
 
@@ -163,20 +123,16 @@ class BooleanConfigRegistry(object):
 class ViewConfigRegistry(_M, BooleanConfigRegistry):
     """Immutable view of UCR."""
 
-    def __init__(self, ucr):
-        # type: (Mapping[str, str]) -> None
+    def __init__(self, ucr: Mapping[str, str]) -> None:
         self.ucr = ucr
 
-    def __getitem__(self, key):
-        # type: (str) -> str
+    def __getitem__(self, key: str) -> str:
         return self.ucr.__getitem__(key)
 
-    def __iter__(self):
-        # type: () -> Iterator[str]
+    def __iter__(self) -> Iterator[str]:
         return self.ucr.__iter__()
 
-    def __len__(self):
-        # type: () -> int
+    def __len__(self) -> int:
         return self.ucr.__len__()
 
 
@@ -199,21 +155,19 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         DEFAULTS: 'base-defaults.conf',
     }
 
-    def __init__(self, filename=""):
-        # type: (str) -> None
-        super(ReadOnlyConfigRegistry, self).__init__()
+    def __init__(self, filename: str = "") -> None:
+        super().__init__()
         custom = os.getenv('UNIVENTION_BASECONF') or filename
         self.autoload = Load.MANUAL
 
-        self._registry = {}  # type: Dict[int, _ConfigRegistry]
+        self._registry: dict[int, _ConfigRegistry] = {}
         for reg in self.LAYER_PRIORITIES:
             if reg == self.CUSTOM:
-                self._registry[reg] = _ConfigRegistry(custom if custom else os.devnull)
+                self._registry[reg] = _ConfigRegistry(custom or os.devnull)
             else:
                 self._registry[reg] = _ConfigRegistry(os.devnull if custom else os.path.join(self.PREFIX, self.BASES[reg]))
 
-    def _walk(self):
-        # type: () -> Iterator[Tuple[int, _ConfigRegistry]]
+    def _walk(self) -> Iterator[tuple[int, Self]]:
         """
         Iterator over layers.
 
@@ -226,8 +180,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
             registry = self._registry[reg]
             yield (reg, registry)
 
-    def load(self, autoload=Load.MANUAL):
-        # type: (_T, Load) -> _T
+    def load(self, autoload: Load = Load.MANUAL) -> Self:
         """
         Load registry from file.
 
@@ -245,8 +198,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
 
         return self
 
-    def __enter__(self):
-        # type: () -> ViewConfigRegistry
+    def __enter__(self) -> ViewConfigRegistry:
         """
         Return immutable view despite `autoload`.
 
@@ -259,12 +211,10 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         """
         return ViewConfigRegistry(self._merge())
 
-    def __exit__(self, exc_type, exc_value, traceback):
-        # type: (Optional[Type[BaseException]], Optional[BaseException], Optional[TracebackType]) -> None
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         """Release registry view."""
 
-    def __getitem__(self, key):  # type: ignore
-        # type: (str) -> Optional[str]
+    def __getitem__(self, key: str) -> str | None:  # type: ignore
         """
         Return registry value.
 
@@ -275,8 +225,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         """
         return self.get(key)
 
-    def __contains__(self, key):  # type: ignore
-        # type: (str) -> bool
+    def __contains__(self, key: str) -> bool:  # type: ignore
         """
         Check if registry key is set.
 
@@ -285,8 +234,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         """
         return any(key in registry for _reg, registry in self._walk())
 
-    def __iter__(self):
-        # type: () -> Iterator[str]
+    def __iter__(self) -> Iterator[str]:
         """
         Iterate over all registry keys.
 
@@ -295,8 +243,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         merge = self._merge()
         yield from merge
 
-    def __len__(self):
-        # type: () -> int
+    def __len__(self) -> int:
         """
         Return length.
 
@@ -306,17 +253,14 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         return len(merge)
 
     @overload  # type: ignore
-    def get(self, key, default, getscope):  # pragma: no cover
-        # type: (str, _VT, Literal[True]) -> Union[Tuple[int, str], _VT]
+    def get(self, key: str, default: _VT, getscope: Literal[True]) -> tuple[int, str] | _VT:  # pragma: no cover
         pass
 
     @overload
-    def get(self, key, default=None):  # pragma: no cover
-        # type: (str, _VT | None) -> Union[str, _VT]
+    def get(self, key: str, default: _VT | None = None) -> str | _VT:  # pragma: no cover
         pass
 
-    def get(self, key, default=None, getscope=False):
-        # type: (str, Optional[_VT], bool) -> Union[str, Tuple[int, str], _VT, None]
+    def get(self, key: str, default: _VT | None = None, getscope: bool = False) -> str | tuple[int, str] | _VT | None:
         """
         Return registry value (including optional scope).
 
@@ -327,7 +271,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         """
         for reg, registry in self._walk():
             try:
-                value = registry[key]  # type: str
+                value: str = registry[key]
             except KeyError:
                 continue
             if reg == self.DEFAULTS:
@@ -336,17 +280,14 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         return default
 
     @overload
-    def get_int(self, key):  # pragma: no cover
-        # type: (str) -> Optional[int]
+    def get_int(self, key: str) -> int | None:  # pragma: no cover
         pass
 
     @overload  # type: ignore
-    def get_int(self, key, default):  # pragma: no cover
-        # type: (str, _VT) -> Union[int, _VT]
+    def get_int(self, key: str, default: _VT) -> int | _VT:  # pragma: no cover
         pass
 
-    def get_int(self, key, default=None):
-        # type: (str, Optional[_VT]) -> Union[int, _VT, None]
+    def get_int(self, key: str, default: _VT | None = None) -> int | _VT | None:
         """
         Return registry value as int.
 
@@ -360,24 +301,21 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
             return default
 
     @overload
-    def _merge(self):  # pragma: no cover
-        # type: () -> Dict[str, str]
+    def _merge(self) -> dict[str, str]:  # pragma: no cover
         pass
 
     @overload
-    def _merge(self, getscope):  # pragma: no cover
-        # type: (Literal[True]) -> Dict[str, Tuple[int, str]]
+    def _merge(self, getscope: Literal[True]) -> dict[str, tuple[int, str]]:  # pragma: no cover
         pass
 
-    def _merge(self, getscope=False):
-        # type: (bool) -> Union[Dict[str, str], Dict[str, Tuple[int, str]]]
+    def _merge(self, getscope: bool = False) -> dict[str, str] | dict[str, tuple[int, str]]:
         """
         Merge sub registry.
 
         :param getscope: `True` makes the method return the scope level in addition to the value itself.
         :returns: A mapping from varibal ename to eiter the value (if `getscope` is False) or a 2-tuple (level, value).
         """
-        merge = {}  # type: Dict[str, Union[str, Tuple[int, str]]]
+        merge: dict[str, str | tuple[int, str]] = {}
         for reg, registry in self._walk():
             for key, value in registry.items():
                 if key not in merge:
@@ -387,8 +325,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
 
         return merge  # type: ignore
 
-    def _eval_default(self, default):
-        # type: (str) -> str
+    def _eval_default(self, default: str) -> str:
         """
         Recursively evaluate default value.
 
@@ -403,17 +340,14 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         return value.decode("UTF-8")
 
     @overload
-    def items(self):  # pragma: no cover
-        # type: () -> ItemsView[str, str]
+    def items(self) -> ItemsView[str, str]:  # pragma: no cover
         pass
 
     @overload
-    def items(self, getscope):  # pragma: no cover
-        # type: (Literal[True]) -> ItemsView[str, Tuple[int, str]]
+    def items(self, getscope: Literal[True]) -> ItemsView[str, tuple[int, str]]:  # pragma: no cover
         pass
 
-    def items(self, getscope=False):
-        # type: (bool) -> Union[ItemsView[str, str], ItemsView[str, Tuple[int, str]]]
+    def items(self, getscope: bool = False) -> ItemsView[str, str] | ItemsView[str, tuple[int, str]]:
         """
         Return all registry entries a 2-tuple (key, value) or (key, (scope, value)) if getscope is True.
 
@@ -423,8 +357,7 @@ class ReadOnlyConfigRegistry(_M, BooleanConfigRegistry):
         merge = self._merge(getscope=getscope)
         return merge.items()  # type: ignore
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         """Return registry content as string."""
         merge = self._merge()
         return '\n'.join(['%s: %s' % (key, val) for key, val in merge.items()])
@@ -439,9 +372,8 @@ class ConfigRegistry(ReadOnlyConfigRegistry, _MM):
     :param write_registry: The UCR level used for writing.
     """
 
-    def __init__(self, filename="", write_registry=ReadOnlyConfigRegistry.NORMAL):
-        # type: (str, int) -> None
-        super(ConfigRegistry, self).__init__(filename)
+    def __init__(self, filename: str = "", write_registry: int = ReadOnlyConfigRegistry.NORMAL) -> None:
+        super().__init__(filename)
         custom = os.getenv('UNIVENTION_BASECONF') or filename
         self.scope = self.CUSTOM if custom else write_registry
         for reg in self.LAYER_PRIORITIES:
@@ -449,28 +381,23 @@ class ConfigRegistry(ReadOnlyConfigRegistry, _MM):
             registry._create_base_conf()
 
     @property
-    def _layer(self):
-        # type: () -> _ConfigRegistry
+    def _layer(self) -> Self:
         """Return selected layer."""
         return self._registry[self.scope]
 
-    def save(self):
-        # type: () -> None
+    def save(self) -> None:
         """Save registry to file."""
         self._layer.save()
 
-    def lock(self):
-        # type: () -> None
+    def lock(self) -> None:
         """Lock registry file."""
         self._layer.lock()
 
-    def unlock(self):
-        # type: () -> None
+    def unlock(self) -> None:
         """Un-lock registry file."""
         self._layer.unlock()
 
-    def __enter__(self):  # type: ignore
-        # type: () -> ConfigRegistry
+    def __enter__(self) -> Self:  # type: ignore
         """
         Lock Config Registry for read-modify-write cycle.
 
@@ -483,20 +410,17 @@ class ConfigRegistry(ReadOnlyConfigRegistry, _MM):
         self.load()
         return self
 
-    def __exit__(self, exc_type, exc_value, traceback):
-        # type: (Optional[Type[BaseException]], Optional[BaseException], Optional[TracebackType]) -> None
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         """Unlock registry."""
         if exc_type is None:
             self.save()
         self.unlock()
 
-    def clear(self):
-        # type: () -> None
+    def clear(self) -> None:
         """Clear all registry keys."""
         self._layer.clear()
 
-    def __delitem__(self, key):
-        # type: (str) -> None
+    def __delitem__(self, key: str) -> None:
         """
         Delete registry key.
 
@@ -504,8 +428,7 @@ class ConfigRegistry(ReadOnlyConfigRegistry, _MM):
         """
         del self._layer[key]
 
-    def __setitem__(self, key, value):
-        # type: (str, str) -> None
+    def __setitem__(self, key: str, value: str) -> None:
         """
         Set registry value.
 
@@ -514,8 +437,7 @@ class ConfigRegistry(ReadOnlyConfigRegistry, _MM):
         """
         self._layer[key] = value
 
-    def update(self, changes):  # type: ignore
-        # type: (Dict[str, Optional[str]]) -> Dict[str, Tuple[Optional[str], Optional[str]]]
+    def update(self, changes: dict[str, str | None]) -> dict[str, tuple[str | None, str | None]]:  # type: ignore
         """
         Set or unset the given config registry variables.
 
@@ -537,8 +459,7 @@ class ConfigRegistry(ReadOnlyConfigRegistry, _MM):
             changed[key] = (old_value, new_value)
         return changed
 
-    def setdefault(self, key, default):  # type: ignore
-        # type: (str, str) -> str
+    def setdefault(self, key: str, default: str) -> str:  # type: ignore
         """
         Set value for variable only when not yet set.
 
@@ -564,8 +485,7 @@ class _ConfigRegistry(dict):
 
     RE_COMMENT = re.compile(r'^[^:]*#.*$')
 
-    def __init__(self, filename):
-        # type: (str) -> None
+    def __init__(self, filename: str) -> None:
         dict.__init__(self)
         self.file = filename
         self.backup_file = self.file + '.bak'
@@ -574,11 +494,10 @@ class _ConfigRegistry(dict):
         # means the backend files are valid UTF-8 and should stay that way -->
         # only accept valid UTF-8
         self.strict_encoding = False
-        self.lock_file = None  # type: Optional[IO]
+        self.lock_file: IO | None = None
         self.mtime = 0.0
 
-    def load(self):
-        # type: () -> None
+    def load(self) -> None:
         """Load sub registry from file."""
         for fn in (self.file, self.backup_file):
             new = {}
@@ -616,8 +535,7 @@ class _ConfigRegistry(dict):
         if fn != self.file:
             self._save_file(self.file)
 
-    def _create_base_conf(self):
-        # type: () -> None
+    def _create_base_conf(self) -> None:
         """Create sub registry file."""
         try:
             reg_file = os.open(self.file, os.O_CREAT | os.O_EXCL | os.O_WRONLY, 0o644)
@@ -629,8 +547,7 @@ class _ConfigRegistry(dict):
             print(msg, file=sys.stderr)
             exception_occured()
 
-    def _save_file(self, filename):
-        # type: (str) -> None
+    def _save_file(self, filename: str) -> None:
         """
         Save sub registry to file.
 
@@ -668,8 +585,7 @@ class _ConfigRegistry(dict):
             if ex.errno != errno.EACCES:
                 raise
 
-    def _save_to(self, filename):
-        # type: (str) -> None
+    def _save_to(self, filename: str) -> None:
         """
         Serialize sub registry to file.
 
@@ -677,26 +593,23 @@ class _ConfigRegistry(dict):
         """
         with open(filename, 'w', encoding='utf-8') as fd:
             # write data to file
-            fd.write(u'# univention_ base.conf\n\n')
+            fd.write('# univention_ base.conf\n\n')
             fd.write(self.__unicode__())
             # flush (meta)data
             fd.flush()
             os.fsync(fd.fileno())
 
-    def save(self):
-        # type: () -> None
+    def save(self) -> None:
         """Save sub registry to file."""
         for filename in (self.backup_file, self.file):
             self._save_file(filename)
 
-    def lock(self):
-        # type: () -> None
+    def lock(self) -> None:
         """Lock sub registry file."""
         self.lock_file = lock = open(self.lock_filename, "a+", encoding='utf-8')
         fcntl.flock(lock.fileno(), fcntl.LOCK_EX)
 
-    def unlock(self):
-        # type: () -> None
+    def unlock(self) -> None:
         """Un-lock sub registry file."""
         if self.lock_file is not None:
             self.lock_file.close()
@@ -721,8 +634,7 @@ class _ConfigRegistry(dict):
         return dict.__setitem__(self, key, value)
 
     @staticmethod
-    def remove_invalid_chars(seq):
-        # type: (str) -> str
+    def remove_invalid_chars(seq: str) -> str:
         """
         Remove non-UTF-8 characters from value.
 
@@ -733,8 +645,7 @@ class _ConfigRegistry(dict):
             seq = seq.replace(letter, '')
         return seq
 
-    def __str__(self):
-        # type: () -> str
+    def __str__(self) -> str:
         """Return sub registry content as string."""
         return '\n'.join(
             '%s: %s' % (key, self.remove_invalid_chars(val))
