@@ -1,31 +1,5 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2022-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2022-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """
 |UCR| type validation classes.
@@ -36,14 +10,15 @@ Checks validity of type definitions and type compatibility of values to be set.
 import ipaddress
 import json
 import re
-from typing import Container, Dict, Iterator, Optional, Pattern, Type as _Type, Union, cast  # noqa: F401
+from collections.abc import Container, Iterator  # noqa: F401
+from typing import cast
 from urllib.parse import urlsplit
 
 import univention.config_registry_info as cri
 from univention.config_registry.backend import BooleanConfigRegistry
 
 
-class BaseValidator(object):
+class BaseValidator:
     """Base class for |UCR| type validators."""
 
     NAME = ""
@@ -159,7 +134,7 @@ class IPv4Address(BaseValidator):
 
     def validate(self, value):
         # type: (str) -> object
-        return ipaddress.IPv4Address(u"%s" % value)  # FIXME: remove Python 2.7 unicoding
+        return ipaddress.IPv4Address("%s" % value)  # FIXME: remove Python 2.7 unicoding
 
 
 class IPv6Address(BaseValidator):
@@ -169,7 +144,7 @@ class IPv6Address(BaseValidator):
 
     def validate(self, value):
         # type: (str) -> object
-        return ipaddress.IPv6Address(u"%s" % value)  # FIXME: remove Python 2.7 unicoding
+        return ipaddress.IPv6Address("%s" % value)  # FIXME: remove Python 2.7 unicoding
 
 
 class IPAddress(BaseValidator):
@@ -179,7 +154,7 @@ class IPAddress(BaseValidator):
 
     def validate(self, value):
         # type: (str) -> object
-        return ipaddress.ip_address(u"%s" % value)  # FIXME: remove Python 2.7 unicoding
+        return ipaddress.ip_address("%s" % value)  # FIXME: remove Python 2.7 unicoding
 
 
 class Integer(BaseValidator):
@@ -198,8 +173,8 @@ class Integer(BaseValidator):
         # type: (Dict[str, str]) -> None
         self._min = None  # type: Optional[int]
         self._max = None  # type: Optional[int]
-        self.min = cast(Optional[int], attrs.get('min', self.MIN))
-        self.max = cast(Optional[int], attrs.get('max', self.MAX))
+        self.min = cast(int | None, attrs.get('min', self.MIN))
+        self.max = cast(int | None, attrs.get('max', self.MAX))
 
     @property
     def min(self):
@@ -242,9 +217,7 @@ class Integer(BaseValidator):
         val = int(value)
         if self._min is not None and val < self._min:
             return False
-        if self._max is not None and val > self._max:
-            return False
-        return True
+        return not (self._max is not None and val > self._max)
 
     def __str__(self):
         # type: () -> str
@@ -341,9 +314,9 @@ class Cron(BaseValidator):
     """Validator for |UCR| type "cron"."""
 
     NAME = "cron"
-    PREDEFINED = frozenset("@annually @yearly @monthly @weekly @daily @hourly @reboot".split())
-    MONTHS = frozenset("jan feb mar apr may jun jul aug sep oct nov dec".split())
-    DAYS = frozenset("sun mon tue wed thu fri sat".split())
+    PREDEFINED = frozenset(["@annually", "@yearly", "@monthly", "@weekly", "@daily", "@hourly", "@reboot"])
+    MONTHS = frozenset(["jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep", "oct", "nov", "dec"])
+    DAYS = frozenset(["sun", "mon", "tue", "wed", "thu", "fri", "sat"])
 
     def validate(self, value):
         # type: (str) -> object
@@ -396,7 +369,7 @@ class Cron(BaseValidator):
                 raise ValueError("step={step!r} not in range [{low_}-{high}]".format(low_=low or 1, **locals()))
 
 
-class Type(object):
+class Type:
     """
     Basic |UCR| type validation class.
 
