@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 # pylint: disable-msg=C0103,E0611,R0904
-# SPDX-FileCopyrightText: 2014-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Unit test for univention.config_registry.backend."""
@@ -9,10 +9,10 @@ from threading import Lock, Thread
 
 import pytest
 
-from univention.config_registry.backend import ConfigRegistry  # noqa: E402
+from univention.config_registry.backend import ConfigRegistry
 
 
-class DummyLock(object):
+class DummyLock:
 
     def __enter__(self):
         pass
@@ -21,8 +21,8 @@ class DummyLock(object):
         pass
 
 
-@pytest.mark.slow()
-class TestConfigRegistry(object):
+@pytest.mark.slow
+class TestConfigRegistry:
     """Unit test for univention.config_registry.backend.ConfigRegistry"""
 
     def test_threading(self):
