@@ -1,6 +1,5 @@
 #!/usr/bin/python3
-# vim:set fileencoding=utf-8:
-# SPDX-FileCopyrightText: 2014-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Unit test for univention.config_registry.frontend."""
@@ -13,13 +12,13 @@ import pytest
 import univention.config_registry.frontend as ucrfe
 
 
-@pytest.fixture()
+@pytest.fixture
 def defaults(mocker):
     """Mock default value registration."""
     return mocker.patch("univention.config_registry.frontend._register_variable_default_values")
 
 
-@pytest.fixture()
+@pytest.fixture
 def gopt():
     """Set global options for frontend handler functions."""
     old = {}
@@ -37,7 +36,7 @@ def gopt():
         ucrfe.OPT_FILTERS[key][2] = value
 
 
-@pytest.fixture()
+@pytest.fixture
 def vinfo():
     """Fake variable info."""
     return {
@@ -48,7 +47,7 @@ def vinfo():
     }
 
 
-@pytest.fixture()
+@pytest.fixture
 def vcinfo():
     """Fake variable info."""
     return {
@@ -59,7 +58,7 @@ def vcinfo():
     }
 
 
-@pytest.fixture()
+@pytest.fixture
 def vrinfo():
     """Fake variable info."""
     return {
@@ -72,7 +71,7 @@ def vrinfo():
     }
 
 
-@pytest.fixture()
+@pytest.fixture
 def rinfo(request, mocker, vinfo, vcinfo, vrinfo):
     """Fake registry info."""
     info = mocker.patch("univention.config_registry.frontend._get_config_registry_info")
@@ -93,7 +92,7 @@ def rinfo(request, mocker, vinfo, vcinfo, vrinfo):
     return info
 
 
-@pytest.fixture()
+@pytest.fixture
 def run(mocker):
     """Mock frontend._run_changed."""
     return mocker.patch("univention.config_registry.frontend._run_changed")
@@ -103,43 +102,43 @@ def test_UnknownKeyException():
     assert str(ucrfe.UnknownKeyException("key")) == 'W: Unknown key: "key"'
 
 
-class TestReplog(object):
+class TestReplog:
 
-    @pytest.fixture()
+    @pytest.fixture
     def replog(self, monkeypatch, tmpdir, ucr0):
         """Empty UCR for replog testing."""
         log = tmpdir / "replog"
         monkeypatch.setattr(ucrfe, "REPLOG_FILE", str(log))
         return log
 
-    @pytest.fixture()
+    @pytest.fixture
     def ucrr(self, ucr0):
         ucr0["ucr/replog/enabled"] = "true"
         return ucr0
 
     def test_replog_new(self, replog, ucrr):
-        ucrfe.replog(ucrr, u"key", None, u"new")
-        assert u": set key=new old:[Previously undefined]\n" in replog.read()
+        ucrfe.replog(ucrr, "key", None, "new")
+        assert ": set key=new old:[Previously undefined]\n" in replog.read()
 
     def test_replog_set(self, replog, ucrr):
-        ucrfe.replog(ucrr, u"key", u"old", u"new")
-        assert u": set key=new old:old\n" in replog.read()
+        ucrfe.replog(ucrr, "key", "old", "new")
+        assert ": set key=new old:old\n" in replog.read()
 
     def test_replog_unset(self, replog, ucrr):
-        ucrfe.replog(ucrr, u"key", u"old")
-        assert u": unset 'key' old:old\n" in replog.read()
+        ucrfe.replog(ucrr, "key", "old")
+        assert ": unset 'key' old:old\n" in replog.read()
 
     def test_replog_error(self, monkeypatch, tmpdir, ucrr):
         log = tmpdir / "dir" / "replog"
         monkeypatch.setattr(ucrfe, "REPLOG_FILE", str(log))
         with pytest.raises(SystemExit) as exc_info:
-            ucrfe.replog(ucrr, u"key", u"old")
+            ucrfe.replog(ucrr, "key", "old")
 
         assert exc_info.value.code != 0
 
     def test_replog_bytes(self, replog, ucrr):
         ucrfe.replog(ucrr, "key", "old", "new")
-        assert u": set key=new old:old\n" in replog.read()
+        assert ": set key=new old:old\n" in replog.read()
 
 
 @pytest.mark.parametrize("opt,scope", [
@@ -154,7 +153,7 @@ def test_ucr_from_opts(opt, scope, mocker):
     ucr.assert_called_once_with(write_registry=getattr(ucr, scope))
 
 
-class TestHandler(object):
+class TestHandler:
 
     CHANGES = {"new": "val", "foo": "foo", "bar": "bar", "baz": None}
     CHANGED = {
@@ -173,7 +172,7 @@ class TestHandler(object):
         mocker.patch("univention.config_registry.frontend._ucr_from_opts", return_value=ucrf)
         return ucrf
 
-    @pytest.fixture()
+    @pytest.fixture
     def handlers(self, mocker):
         h = mocker.patch("univention.config_registry.frontend.ConfigHandlers")
         h.return_value.update.return_value = set()
@@ -409,7 +408,7 @@ class TestHandler(object):
         assert err == 'W: Unknown key: "key"\n'
 
 
-class TestInfo(object):
+class TestInfo:
 
     def test_unset(self):
         with pytest.raises(ucrfe.UnknownKeyException):
@@ -487,14 +486,14 @@ def test_registry_variable_default_values(ucrf, rinfo, run, mocker):
     run.assert_called_once_with(ucrf, {"key": (None, "default")}, mocker.ANY)
 
 
-class TestMain(object):
+class TestMain:
 
     @pytest.fixture(autouse=True)
     def reset(self):
         """Reset frontend global state."""
         reload(ucrfe)
 
-    @pytest.fixture()
+    @pytest.fixture
     def handlers(self, mocker, reset):
         """Mock frontend handlers."""
         h = {
