@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 # pylint: disable-msg=C0103,E0611,R0904
-# SPDX-FileCopyrightText: 2014-2024 Univention GmbH
+# SPDX-FileCopyrightText: 2014-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Unit test for :py:mod:`univention.config_registry_info`"""
@@ -21,12 +21,12 @@ def _variable():
     return v
 
 
-@pytest.fixture()
+@pytest.fixture
 def variable():
     return _variable()
 
 
-@pytest.fixture()
+@pytest.fixture
 def category():
     """Complete UCR category description."""
     c = ucri.Category()
@@ -35,7 +35,7 @@ def category():
     return c
 
 
-class TestVariable(object):
+class TestVariable:
 
     def test_unreg(self):
         v = ucri.Variable(registered=False)
@@ -55,7 +55,7 @@ class TestVariable(object):
         assert variable.check() == []
 
 
-class TestCategory(object):
+class TestCategory:
 
     def test_incomplete(self):
         c = ucri.Category()
@@ -71,7 +71,7 @@ class TestCategory(object):
         assert category.check() == []
 
 
-class TestConfigRegistryInfo(object):
+class TestConfigRegistryInfo:
 
     @pytest.fixture(autouse=True)
     def setup0(self, tmpdir, monkeypatch):
@@ -82,7 +82,7 @@ class TestConfigRegistryInfo(object):
         variables = base.join(ucri.ConfigRegistryInfo.VARIABLES)
         return Namespace(base=base, categories=categories, variables=variables)
 
-    @pytest.fixture()
+    @pytest.fixture
     def setup(self, setup0):
         """Fake populated UCR info files."""
         setup0.categories.mkdir()
@@ -95,12 +95,12 @@ class TestConfigRegistryInfo(object):
         setup0.variables.join("d.cfg").write("[key/.*/abc]\nDescription=description\nType=int\nCategories=category\n\n")
         return setup0
 
-    @pytest.fixture()
+    @pytest.fixture
     def info0(self, setup0):
         """Empty registry info instance."""
         return ucri.ConfigRegistryInfo(install_mode=True)
 
-    @pytest.fixture()
+    @pytest.fixture
     def info(self, setup):
         """Registry info instance."""
         return ucri.ConfigRegistryInfo()
